import pytest
import nlzss11
# reference implementation
from lzss3 import decompress_bytes
from pathlib import Path
from files import TEST_FILES, TEST_FILE_DATA, TEST_FILE_DATA_UNCOMP


@pytest.mark.parametrize("file", TEST_FILES)
def test_decompression(file):
    assert TEST_FILE_DATA_UNCOMP[file] == nlzss11.decompress(TEST_FILE_DATA[file])


@pytest.mark.parametrize("file", TEST_FILES)
def test_roundtrip(file):
    assert TEST_FILE_DATA_UNCOMP[file] == nlzss11.decompress(nlzss11.compress(TEST_FILE_DATA_UNCOMP[file]))


@pytest.mark.parametrize("file", TEST_FILES)
def test_compress(file):
    assert TEST_FILE_DATA_UNCOMP[file] == decompress_bytes(bytes(nlzss11.compress(TEST_FILE_DATA_UNCOMP[file])))
    


import pytest
import nlzss11
from lzss3 import decompress_bytes
from files import TEST_FILES, TEST_FILE_DATA


@pytest.mark.parametrize("file", TEST_FILES)
def test_lzss3(benchmark, file):
    benchmark.group = "decomp: " + file
    benchmark(decompress_bytes, TEST_FILE_DATA[file])

@pytest.mark.parametrize("file", TEST_FILES)
def test_nlzss11(benchmark, file):
    benchmark.group = "decomp: " + file
    benchmark(nlzss11.decompress, TEST_FILE_DATA[file])


@pytest.mark.parametrize("file", TEST_FILES)
def test_nlzss11_fast(benchmark, file):
    benchmark.group = "decomp: " + file
    benchmark(nlzss11.decompress_unsafe, TEST_FILE_DATA[file])



import pytest
import nlzss11
from files import TEST_FILES, TEST_FILE_DATA, TEST_FILE_DATA_UNCOMP

@pytest.mark.parametrize("file", TEST_FILES)
def test_comp_nlzss11_lv6(benchmark, file):
    benchmark.group = "comp: " + file
    benchmark(nlzss11.compress, TEST_FILE_DATA_UNCOMP[file], level=6)


@pytest.mark.parametrize("file", TEST_FILES)
def test_comp_nlzss11_lv7(benchmark, file):
    benchmark.group = "comp: " + file
    benchmark(nlzss11.compress, TEST_FILE_DATA_UNCOMP[file], level=7)


@pytest.mark.parametrize("file", TEST_FILES)
def test_comp_nlzss11_lv8(benchmark, file):
    benchmark.group = "comp: " + file
    benchmark(nlzss11.compress, TEST_FILE_DATA_UNCOMP[file], level=8)


@pytest.mark.parametrize("file", TEST_FILES)
def test_comp_nlzss11_lv9(benchmark, file):
    benchmark.group = "comp: " + file
    benchmark(nlzss11.compress, TEST_FILE_DATA_UNCOMP[file], level=9)